@@ -1,18 +1,9 @@
 /*
  * This file is part of TbSync.
  *
- * TbSync is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
- *
- * TbSync is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with TbSync. If not, see <https://www.gnu.org/licenses/>.
+ * This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/. 
  */
  
  "use strict";
@@ -31,32 +22,17 @@ var tbSyncAccounts = {
     onload: function () {
         //scan accounts, update list and select first entry (because no id is passed to updateAccountList)
         //the onSelect event of the List will load the selected account
-        this.updateAccountsList(); 
+        //also update/init add menu
+        this.updateAccountsList(-1, true); 
+        
+        Services.obs.addObserver(tbSyncAccounts.updateAccountsListObserver, "tbsync.updateAccountsList", false);
         Services.obs.addObserver(tbSyncAccounts.updateAccountSyncStateObserver, "tbsync.updateSyncstate", false);
         Services.obs.addObserver(tbSyncAccounts.updateAccountNameObserver, "tbsync.updateAccountName", false);
         Services.obs.addObserver(tbSyncAccounts.toggleEnableStateObserver, "tbsync.toggleEnableState", false);
-        
-        //prepare addmenu
-        for (let provider in tbSync.providerList) {
-            if (tbSync.providerList[provider].enabled || tbSync.providerList[provider].homepageUrl != "") {
-                let newItem = window.document.createElement("menuitem");
-                newItem.setAttribute("value", provider);
-                newItem.setAttribute("label", tbSync.providerList[provider].name);
-                newItem.setAttribute("class", "menuitem-iconic");
-                if (tbSync.providerList[provider].enabled) {
-                    newItem.addEventListener("click", function () {tbSyncAccounts.addAccount(provider) }, false);
-                    newItem.setAttribute("src", tbSync[provider].getProviderIcon());
-                } else {
-                    newItem.addEventListener("click", function () {tbSyncAccounts.installProvider(provider) }, false);
-                    newItem.setAttribute("src", "chrome://tbsync/skin/provider16.png");                    
-                }
-                window.document.getElementById("accountActionsAddAccount").appendChild(newItem);
-            }
-        }
-        
     },
 
     onunload: function () {
+        Services.obs.removeObserver(tbSyncAccounts.updateAccountsListObserver, "tbsync.updateAccountsList");
         Services.obs.removeObserver(tbSyncAccounts.updateAccountSyncStateObserver, "tbsync.updateSyncstate");
         Services.obs.removeObserver(tbSyncAccounts.updateAccountNameObserver, "tbsync.updateAccountName");
         Services.obs.removeObserver(tbSyncAccounts.toggleEnableStateObserver, "tbsync.toggleEnableState");
@@ -65,7 +41,7 @@ var tbSyncAccounts = {
     debugToggleAll: function () {
         let accounts = tbSync.db.getAccounts();
         for (let i=0; i < accounts.IDs.length; i++) {
-            tbSyncAccounts.toggleAccountEnableState(accounts.IDs[i], true);
+            tbSyncAccounts.toggleAccountEnableState(accounts.IDs[i]);
         }
     },
     
@@ -409,12 +385,10 @@ var tbSyncAccounts = {
         }
     },
         
-    addAccount: function (provider) {
-        document.getElementById("tbSyncAccounts.accounts").disabled=true;
-        document.getElementById("tbSyncAccounts.btnAccountActions").disabled=true;
-        window.openDialog("chrome:" + tbSync.providerList[provider].newXul, "newaccount", "centerscreen,modal,resizable=no");
-        document.getElementById("tbSyncAccounts.accounts").disabled=false;
-        document.getElementById("tbSyncAccounts.btnAccountActions").disabled=false;
+    
+    hasInstalledProvider: function (accountID) {
+        let provider = tbSync.db.getAccountSetting(accountID, "provider");
+        return tbSync.loadedProviders.hasOwnProperty(provider);
     },
 
     updateDropdown: function (selector) {
@@ -426,6 +400,7 @@ var tbSyncAccounts = {
         let isSyncing = false;
         let isConnected = false;
         let isEnabled = false;
+        let isInstalled = false;
         
         if (accountsList.selectedItem !== null && !isNaN(accountsList.selectedItem.value)) {
             //some item is selected
@@ -435,6 +410,7 @@ var tbSyncAccounts = {
             isSyncing = tbSync.isSyncing(selectedAccount);
             isConnected = tbSync.isConnected(selectedAccount);
             isEnabled = tbSync.isEnabled(selectedAccount);
+            isInstalled = tbSyncAccounts.hasInstalledProvider(selectedAccount);
         }
         
         //hide if no accounts are avail (which is identical to no account selected)
@@ -443,14 +419,16 @@ var tbSyncAccounts = {
         //hide if no account is selected
         if (isActionsDropdown) document.getElementById(selector + "Separator").hidden = (selectedAccount === null);
         document.getElementById(selector + "DeleteAccount").hidden = (selectedAccount === null);
-        document.getElementById(selector + "DisableAccount").hidden = (selectedAccount === null) || !isEnabled;
-        document.getElementById(selector + "EnableAccount").hidden = (selectedAccount === null) || isEnabled;
-        document.getElementById(selector + "SyncAccount").hidden = (selectedAccount === null) || !isConnected;
-        document.getElementById(selector + "RetryConnectAccount").hidden = (selectedAccount === null) || isConnected || !isEnabled;
+        document.getElementById(selector + "DisableAccount").hidden = (selectedAccount === null) || !isEnabled || !isInstalled;
+        document.getElementById(selector + "EnableAccount").hidden = (selectedAccount === null) || isEnabled || !isInstalled;
+        document.getElementById(selector + "SyncAccount").hidden = (selectedAccount === null) || !isConnected || !isInstalled;
+        document.getElementById(selector + "RetryConnectAccount").hidden = (selectedAccount === null) || isConnected || !isEnabled || !isInstalled;
 
         //Not yet implemented
-        document.getElementById(selector + "ShowSyncLog").hidden = true;//(selectedAccount === null) || !isEnabled;
-        document.getElementById(selector + "ShowSyncLog").disabled = true;
+        if (document.getElementById(selector + "ShowErrorLog")) {
+            document.getElementById(selector + "ShowErrorLog").hidden = false;
+            document.getElementById(selector + "ShowErrorLog").disabled = false;
+        }
         
         if (selectedAccount !== null) {
             //disable if currently syncing (and displayed)
@@ -474,13 +452,14 @@ var tbSyncAccounts = {
             document.getElementById("accountActionsDebugDel").hidden = !tbSync.prefSettings.getBoolPref("debug.testoptions");
             document.getElementById("accountActionsSeparatorDebug").hidden = !tbSync.prefSettings.getBoolPref("debug.testoptions");
         }
-
     },
     
     synchronizeAccount: function () {
         let accountsList = document.getElementById("tbSyncAccounts.accounts");
         if (accountsList.selectedItem !== null && !isNaN(accountsList.selectedItem.value)  && !tbSync.isSyncing(accountsList.selectedItem.value)) {            
-            tbSync.syncAccount('sync', accountsList.selectedItem.value);
+            if (tbSyncAccounts.hasInstalledProvider(accountsList.selectedItem.value)) {
+                tbSync.syncAccount('sync', accountsList.selectedItem.value);
+            }
         }
     },
 
@@ -494,51 +473,72 @@ var tbSyncAccounts = {
                 else nextAccount = accountsList.getItemAtIndex(accountsList.selectedIndex - 1).value;
             }
             
-            if (confirm(tbSync.getLocalizedMessage("prompt.DeleteAccount").replace("##accountName##", accountsList.selectedItem.getAttribute("label")))) {
+            if (!tbSyncAccounts.hasInstalledProvider(accountsList.selectedItem.value)) {
+                if (confirm(tbSync.getLocalizedMessage("prompt.EraseAccount").replace("##accountName##", accountsList.selectedItem.getAttribute("label")))) {
+                    //delete account and all folders from db
+                    tbSync.db.removeAccount(accountsList.selectedItem.value);
+                    //update list
+                    this.updateAccountsList(nextAccount);
+                } 
+            } else if (confirm(tbSync.getLocalizedMessage("prompt.DeleteAccount").replace("##accountName##", accountsList.selectedItem.getAttribute("label")))) {
                 //cache all folders and remove associated targets 
                 tbSync.disableAccount(accountsList.selectedItem.value);
-
                 //delete account and all folders from db
                 tbSync.db.removeAccount(accountsList.selectedItem.value);
-
+                //update list
                 this.updateAccountsList(nextAccount);
             }
         }
     },
 
 
+
     /* * *
-    * Observer to catch enable state toggle
+    * Observer to catch update list request (upon provider load/unload)
     */
-    toggleEnableStateObserver: {
+    updateAccountsListObserver: {
         observe: function (aSubject, aTopic, aData) {
-            tbSyncAccounts.toggleAccountEnableState(aData, false);
+            //-2 = try to keep current selection while adding/removing provider aData
+            tbSyncAccounts.updateAccountsList(-2, aData); 
         }
     },
 
     toggleEnableState: function () {
         let accountsList = document.getElementById("tbSyncAccounts.accounts");
+        
         if (accountsList.selectedItem !== null && !isNaN(accountsList.selectedItem.value) && !tbSync.isSyncing(accountsList.selectedItem.value)) {            
-            tbSyncAccounts.toggleAccountEnableState(accountsList.selectedItem.value, false);
+            let isConnected = tbSync.isConnected(accountsList.selectedItem.value);
+            if (!isConnected || window.confirm(tbSync.getLocalizedMessage("prompt.Disable"))) {           
+                tbSyncAccounts.toggleAccountEnableState(accountsList.selectedItem.value);
+            }
+        }
+    },
+
+    /* * *
+    * Observer to catch enable state toggle
+    */
+    toggleEnableStateObserver: {
+        observe: function (aSubject, aTopic, aData) {
+            tbSyncAccounts.toggleAccountEnableState(aData);
         }
     },
     
-    toggleAccountEnableState: function (account, doNotAsk) {
-        let isConnected = tbSync.isConnected(account);
-        let isEnabled = tbSync.isEnabled(account);
-        
-        if (isEnabled) {
-            //we are enabled and want to disable (do not ask, if not connected)
-            if (doNotAsk || !isConnected || window.confirm(tbSync.getLocalizedMessage("prompt.Disable"))) {
+    //is not prompting, this is doing the actual toggle
+    toggleAccountEnableState: function (account) {
+        if (tbSyncAccounts.hasInstalledProvider(account)) {
+            let isEnabled = tbSync.isEnabled(account);
+            
+            if (isEnabled) {
+                //we are enabled and want to disable (do not ask, if not connected)
                 tbSync.disableAccount(account);
                 Services.obs.notifyObservers(null, "tbsync.updateAccountSettingsGui", account);
                 tbSyncAccounts.updateAccountStatus(account);
+            } else {
+                //we are disabled and want to enabled
+                tbSync.enableAccount(account);
+                Services.obs.notifyObservers(null, "tbsync.updateAccountSettingsGui", account);
+                tbSync.syncAccount("sync", account);
             }
-        } else {
-            //we are disabled and want to enabled
-            tbSync.enableAccount(account);
-            Services.obs.notifyObservers(null, "tbsync.updateAccountSettingsGui", account);
-            tbSync.syncAccount("sync", account);
         }
     },
 
@@ -563,62 +563,77 @@ var tbSyncAccounts = {
     
     getStatusImage: function (account, current = "") {
         let src = "";   
-        switch (tbSync.db.getAccountSetting(account, "status").split(".")[0]) {
-            case "OK":
-                src = "tick16.png";
-                break;
-            
-            case "disabled":
-                src = "disabled16.png";
-                break;
-            
-            case "info":
-            case "nolightning":
-                src = "info16.png";
-                break;
 
-            case "warning":
-            case "needtorevert":
-            case "notsyncronized":
-            case "modified":
-                src = "warning16.png";
-                break;
+        if (!tbSyncAccounts.hasInstalledProvider(account)) {
+            src = "error16.png";
+        } else {
+            switch (tbSync.db.getAccountSetting(account, "status").split(".")[0]) {
+                case "OK":
+                    src = "tick16.png";
+                    break;
+                
+                case "disabled":
+                    src = "disabled16.png";
+                    break;
+                
+                case "info":
+                case "nolightning":
+                case "notsyncronized":
+                case "modified":
+                    src = "info16.png";
+                    break;
 
-            case "syncing":
-                switch (current.replace("chrome://tbsync/skin/","")) {
-                    case "sync16_1.png": 
-                        src = "sync16_2.png"; 
-                        break;
-                    case "sync16_2.png": 
-                        src = "sync16_3.png"; 
-                        break;
-                    case "sync16_3.png": 
-                        src = "sync16_4.png"; 
-                        break;
-                    case "sync16_4.png": 
-                        src = "sync16_1.png"; 
-                        break;
-                    default: 
-                        src = "sync16_1.png";
-                        tbSync.setSyncData(account, "accountManagerLastUpdated", 0)
-                        break;
-                }                
-                if ((Date.now() - tbSync.getSyncData(account, "accountManagerLastUpdated")) < 300) {
-                    return current;
-                }
-                tbSync.setSyncData(account, "accountManagerLastUpdated", Date.now());
-                break;
+                case "warning":
+                    src = "warning16.png";
+                    break;
 
-            default:
-                src = "error16.png";
+                case "syncing":
+                    switch (current.replace("chrome://tbsync/skin/","")) {
+                        case "sync16_1.png": 
+                            src = "sync16_2.png"; 
+                            break;
+                        case "sync16_2.png": 
+                            src = "sync16_3.png"; 
+                            break;
+                        case "sync16_3.png": 
+                            src = "sync16_4.png"; 
+                            break;
+                        case "sync16_4.png": 
+                            src = "sync16_1.png"; 
+                            break;
+                        default: 
+                            src = "sync16_1.png";
+                            tbSync.setSyncData(account, "accountManagerLastUpdated", 0)
+                            break;
+                    }                
+                    if ((Date.now() - tbSync.getSyncData(account, "accountManagerLastUpdated")) < 300) {
+                        return current;
+                    }
+                    tbSync.setSyncData(account, "accountManagerLastUpdated", Date.now());
+                    break;
+
+                default:
+                    src = "error16.png";
+            }
         }
-
+        
         return "chrome://tbsync/skin/" + src;
     },
 
+    updateAccountLogo: function (id) {
+        let listItem = document.getElementById("tbSyncAccounts.accounts." + id);
+        if (listItem) {
+            let obj = listItem.childNodes[0].firstChild
+            obj.src = tbSyncAccounts.hasInstalledProvider(id) ? tbSync[tbSync.db.getAccountSetting(id,"provider")].getProviderIcon(16, id) : "chrome://tbsync/skin/provider16.png";
+        }
+    },
+
     updateAccountStatus: function (id) {
         let listItem = document.getElementById("tbSyncAccounts.accounts." + id);
-        if (listItem) this.setStatusImage(id, listItem.childNodes[2].firstChild);
+        if (listItem) {
+            let obj = listItem.childNodes[2].firstChild
+            this.setStatusImage(id, obj);
+        }
     },
 
     updateAccountNameObserver: {
@@ -638,39 +653,44 @@ var tbSyncAccounts = {
         }
     },
     
-    updateAccountsList: function (accountToSelect = -1) {
+    updateAccountsList: function (accountToSelect = -1, updAddMenu = false) {
         let accountsList = document.getElementById("tbSyncAccounts.accounts");
         let accounts = tbSync.db.getAccounts();
 
-        if (accounts.IDs.length > null) {
+        //try to keep the currently selected account, if accountToSelect == -2
+        if (accountToSelect == -2) {
+            let s = accountsList.getItemAtIndex(accountsList.selectedIndex);
+            accountToSelect = s ? s.value : -1;
+        }
+        
+        if (accounts.allIDs.length > null) {
 
             //get current accounts in list and remove entries of accounts no longer there
             let listedAccounts = [];
             for (let i=accountsList.getRowCount()-1; i>=0; i--) {
                 listedAccounts.push(accountsList.getItemAtIndex (i).value);
-                if (accounts.IDs.indexOf(accountsList.getItemAtIndex(i).value) == -1) {
+                if (accounts.allIDs.indexOf(accountsList.getItemAtIndex(i).value) == -1) {
                     accountsList.removeItemAt(i);
                 }
             }
 
             //accounts array is without order, extract keys (ids) and loop over keys
-            for (let i = 0; i < accounts.IDs.length; i++) {
+            for (let i = 0; i < accounts.allIDs.length; i++) {
 
-                if (listedAccounts.indexOf(accounts.IDs[i]) == -1) {
+                if (listedAccounts.indexOf(accounts.allIDs[i]) == -1) {
                     //add all missing accounts (always to the end of the list)
                     let newListItem = document.createElement("richlistitem");
-                    newListItem.setAttribute("id", "tbSyncAccounts.accounts." + accounts.IDs[i]);
-                    newListItem.setAttribute("value", accounts.IDs[i]);
-                    newListItem.setAttribute("label", accounts.data[accounts.IDs[i]].accountname);
+                    newListItem.setAttribute("id", "tbSyncAccounts.accounts." + accounts.allIDs[i]);
+                    newListItem.setAttribute("value", accounts.allIDs[i]);
+                    newListItem.setAttribute("label", accounts.data[accounts.allIDs[i]].accountname);
                     newListItem.setAttribute("ondblclick", "tbSyncAccounts.toggleEnableState();");
                     
-                    //add icon
+                    //add icon (use "install provider" icon, if provider not installed)
                     let itemTypeCell = document.createElement("listcell");
                     itemTypeCell.setAttribute("class", "img");
                     itemTypeCell.setAttribute("width", "24");
                     itemTypeCell.setAttribute("height", "24");
                         let itemType = document.createElement("image");
-                        itemType.setAttribute("src", tbSync[accounts.data[accounts.IDs[i]].provider].getProviderIcon());
                         itemType.setAttribute("style", "margin: 4px;");
                     itemTypeCell.appendChild(itemType);
                     newListItem.appendChild(itemTypeCell);
@@ -679,7 +699,6 @@ var tbSyncAccounts = {
                     let itemLabelCell = document.createElement("listcell");
                     itemLabelCell.setAttribute("class", "label");
                     itemLabelCell.setAttribute("flex", "1");
-                    itemLabelCell.setAttribute("label", accounts.data[accounts.IDs[i]].accountname);
                     newListItem.appendChild(itemLabelCell);
 
                     //add account status
@@ -688,17 +707,17 @@ var tbSyncAccounts = {
                     itemStatusCell.setAttribute("width", "30");
                     itemStatusCell.setAttribute("height", "30");
                     let itemStatus = document.createElement("image");
-                    itemStatus.setAttribute("src", this.getStatusImage(accounts.IDs[i]));
                     itemStatus.setAttribute("style", "margin:2px;");
                     itemStatusCell.appendChild(itemStatus);
 
                     newListItem.appendChild(itemStatusCell);
                     accountsList.appendChild(newListItem);
-                } else {
-                    //update existing entries in list
-                    this.updateAccountName(accounts.IDs[i], accounts.data[accounts.IDs[i]].accountname);
-                    this.updateAccountStatus(accounts.IDs[i]);
-                }
+                } 
+                
+                //update/set actual values
+                this.updateAccountName(accounts.allIDs[i], accounts.data[accounts.allIDs[i]].accountname);
+                this.updateAccountStatus(accounts.allIDs[i]);
+                this.updateAccountLogo(accounts.allIDs[i]);
             }
             
             //find selected item
@@ -715,11 +734,61 @@ var tbSyncAccounts = {
             for (let i=accountsList.getRowCount()-1; i>=0; i--) {
                 accountsList.removeItemAt(i);
             }
-            
             document.getElementById("tbSyncAccounts.contentFrame").setAttribute("src", "chrome://tbsync/content/manager/noaccounts.xul");
         }
+        
+        
+        //updAddMenu can be 
+        // - true (build from scratch)
+        // - false (do nothing)
+        // - a string (add/remove given provider)
+        if (updAddMenu === true) {
+            //add default providers
+            for (let provider in tbSync.defaultProviders) {
+                tbSyncAccounts.updateAddMenuEntry(provider);
+            }
+            //update/add all remaining installed providers
+            for (let provider in tbSync.loadedProviders) {
+                tbSyncAccounts.updateAddMenuEntry(provider);
+            }
+        } else if (updAddMenu !== false) {
+            //update single provider entry
+            tbSyncAccounts.updateAddMenuEntry(updAddMenu);
+            if (accountToSelect != -1 && tbSync.db.getAccountSetting(accountToSelect, "provider") == updAddMenu) {
+                tbSyncAccounts.loadSelectedAccount();
+            }
+        }
     },
 
+    updateAddMenuEntry: function (provider) {
+        let isDefault = tbSync.defaultProviders.hasOwnProperty(provider);
+        let isInstalled = tbSync.loadedProviders.hasOwnProperty(provider);
+        
+        let entry = document.getElementById("addMenuEntry_" + provider);
+        if (entry === null) {
+            //add basic menu entry
+            let newItem = window.document.createElement("menuitem");
+            newItem.setAttribute("id", "addMenuEntry_" + provider);
+            newItem.setAttribute("value",  provider);
+            newItem.setAttribute("class", "menuitem-iconic");
+            newItem.addEventListener("click", function () {tbSyncAccounts.addAccountAction(provider)}, false);
+            newItem.setAttribute("hidden", true);
+            entry = window.document.getElementById("accountActionsAddAccount").appendChild(newItem);
+        }
+        
+        //Update label, icon and hidden according to isDefault and isInstalled
+        if (isInstalled) {
+            entry.setAttribute("label",  tbSync[provider].getNiceProviderName());
+            entry.setAttribute("src", tbSync[provider].getProviderIcon(16));
+            entry.setAttribute("hidden", false);
+        } else if (isDefault) {
+            entry.setAttribute("label", tbSync.defaultProviders[provider].name);
+            entry.setAttribute("src", "chrome://tbsync/skin/provider16.png");                    
+            entry.setAttribute("hidden", false);
+        } else {
+            entry.setAttribute("hidden", true);
+        }
+    },
 
     //load the pref page for the currently selected account (triggered by onSelect)
     loadSelectedAccount: function () {
@@ -727,12 +796,45 @@ var tbSyncAccounts = {
         if (accountsList.selectedItem !== null && !isNaN(accountsList.selectedItem.value)) {
             //get id of selected account from value of selectedItem
             this.selectedAccount = accountsList.selectedItem.value;
-            document.getElementById("tbSyncAccounts.contentFrame").setAttribute("src", "chrome:" + tbSync.providerList[tbSync.db.getAccountSetting(this.selectedAccount, "provider")].accountXul+"?id=" + this.selectedAccount);
+            let provider = tbSync.db.getAccountSetting(this.selectedAccount, "provider");
+            
+            if (tbSyncAccounts.hasInstalledProvider(this.selectedAccount)) {
+                document.getElementById("tbSyncAccounts.contentFrame").setAttribute("src", "chrome://tbsync/content/manager/editAccount.xul?provider="+provider+"&id=" + this.selectedAccount);
+            } else {
+                document.getElementById("tbSyncAccounts.contentFrame").setAttribute("src", "chrome://tbsync/content/manager/missingProvider.xul?provider="+provider);
+            }
         }
     },
     
+
+
+
+    addAccountAction: function (provider) {
+        let isDefault = tbSync.defaultProviders.hasOwnProperty(provider);
+        let isInstalled = tbSync.loadedProviders.hasOwnProperty(provider);
+        
+        if (isInstalled) {
+            tbSyncAccounts.addAccount(provider);
+        } else if (isDefault) {
+            tbSyncAccounts.installProvider(provider);
+        }
+    },
+    
+    addAccount: function (provider) {
+        document.getElementById("tbSyncAccounts.accounts").disabled=true;
+        document.getElementById("tbSyncAccounts.btnAccountActions").disabled=true;
+        window.openDialog(tbSync[provider].getCreateAccountXulUrl(), "newaccount", "centerscreen,modal,resizable=no");
+        document.getElementById("tbSyncAccounts.accounts").disabled=false;
+        document.getElementById("tbSyncAccounts.btnAccountActions").disabled=false;
+    },
+
     installProvider: function (provider) {
-        tbSync.prefWindowObj.document.getElementById("tbSyncAccountManager.t0").setAttribute("active","false");
-        window.location="chrome://tbsync/content/manager/installProvider.xul?provider="+provider;
-    }
+        for (let i=0; i<tbSync.AccountManagerTabs.length; i++) {            
+             tbSync.prefWindowObj.document.getElementById("tbSyncAccountManager.t" + i).setAttribute("active","false");
+        }
+        tbSync.prefWindowObj.document.getElementById("tbSyncAccountManager.installProvider").hidden=false;
+        tbSync.prefWindowObj.document.getElementById("tbSyncAccountManager.installProvider").setAttribute("active","true");
+        tbSync.prefWindowObj.document.getElementById("tbSyncAccountManager.contentWindow").setAttribute("src", "chrome://tbsync/content/manager/installProvider.xul?provider="+provider);        
+    },
+            
 };
